<?php
/**
*
* @author MarkDHamill (Mark D Hamill) mark@phpbbservices.com
* @package umil
* @version $Id umil_smartfeed_install.php 2.2.17 2009-11-08 02:51:30GMT MarkDHamill $
* @copyright (c) 2009 Mark D Hamill
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
define('IN_PHPBB', true);
$phpbb_root_path = (defined('PHPBB_ROOT_PATH')) ? PHPBB_ROOT_PATH : './';
$phpEx = substr(strrchr(__FILE__, '.'), 1);
include($phpbb_root_path . 'common.' . $phpEx);

// Start session management
$user->session_begin();
$auth->acl($user->data);
$user->setup('mods/smartfeed');
$user->setup('acp/common');

if (!file_exists($phpbb_root_path . 'umil/umil.' . $phpEx))
{
	trigger_error('Please download the latest UMIL (Unified MOD Install Library) from: <a href="http://www.phpbb.com/mods/umil/">phpBB.com/mods/umil</a>', E_USER_ERROR);
}

// We only allow a founder to install this MOD
if ($user->data['user_type'] != USER_FOUNDER)
{
	if ($user->data['user_id'] == ANONYMOUS)
	{
		login_box('', 'LOGIN');
	}
	trigger_error('NOT_AUTHORISED');
}

if (!class_exists('umil'))
{
	include($phpbb_root_path . 'umil/umil.' . $phpEx);
}

$umil = new umil(true);

$mod = array(
	'name'		=> 'phpBB Smartfeed',
	'version'	=> '2.2.17',
	'config'	=> 'sf_version',
);

if (confirm_box(true))
{
	// Install the base 2.2.17 version
	if (!$umil->config_exists($mod['config']))
	{
		
		// We must handle the version number ourselves.
		$umil->config_add($mod['config'], $mod['version']);

		// Set other configuration variables
		$umil->config_add('sf_all_by_default', true);
		$umil->config_add('sf_apache_htaccess_enabled', false);
		$umil->config_add('sf_atom_10_value', 'ATOM1.0');
		$umil->config_add('sf_auto_advertise_public_feed', true);
		$umil->config_add('sf_default_fetch_time_limit', (30 * 24));
		$umil->config_add('sf_feed_image_path', 'imageset/site_logo.gif');
		$umil->config_add('sf_max_items', 0);
		$umil->config_add('sf_max_size', 0);
		$umil->config_add('sf_new_post_notifications_only', 0);
		$umil->config_add('sf_privacy_mode', true);
		$umil->config_add('sf_public_feed_url_suffix_atom', 'feed_type=ATOM1.0&amp;limit=%s&amp;sort_by=%s&amp;feed_style=%s&amp');
		$umil->config_add('sf_public_feed_url_suffix_rss', 'feed_type=RSS2.0&amp;limit=%s&amp;sort_by=%s&amp;feed_style=%s&amp');
		$umil->config_add('sf_require_ip_authentication', false);
		$umil->config_add('sf_rfc1766_lang', 'en-GB');
		$umil->config_add('sf_rss_10_value', 'RSS1.0');
		$umil->config_add('sf_rss_20_value', 'RSS2.0');
		$umil->config_add('sf_show_sessions', false);
		$umil->config_add('sf_show_username_in_first_topic_post', true);
		$umil->config_add('sf_show_username_in_replies', true);
		$umil->config_add('sf_smartfeed_host', 'phpbbservices.com');
		$umil->config_add('sf_smartfeed_page_url', 'http://phpbbservices.com/smartfeed/');
		$umil->config_add('sf_smartfeed_title', 'phpBB Smartfeed');
		$umil->config_add('sf_smartfeed_title_short', 'Smartfeed');
		$umil->config_add('sf_suppress_forum_names', false);
		$umil->config_add('sf_ttl', '60');
		$umil->config_add('sf_webmaster','');

		// Extend the phpbb_users_table with additional columns
		$umil->table_column_add(USERS_TABLE, 'user_smartfeed_key', array('VCHAR:32', ''));
		
		// Add the Smartfeed Settings under the Board Configuration category in the ACP.
		$umil->module_add(array(
			array('acp', 'ACP_BOARD_CONFIGURATION', array(
					'module_basename'   => 'board',
					'module_langname'   => 'ACP_SMARTFEED_SETTINGS',
					'module_mode'       => 'smartfeed',
					'module_auth'       => 'acl_a_board',
				),
			),
		));

		// Our final action, we purge the board cache
		$umil->cache_purge();
		
	}

	// We are done
	trigger_error('Done!');
}
else
{
	confirm_box(false, sprintf($user->lang['SMARTFEED_INSTALL_MOD_CONFIRM'], $mod['name']));
}

// Shouldn't get here.
redirect($phpbb_root_path . $user->page['page_name']);

?>